/* Copyright (c) 2015, Electric Cloud, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/* (As an historical note, the above license instantiates
 * the "BSD 2-Clause License" template that was presented
 * by the Open Source Initiative at
 *
 *   http://www.opensource.org/licenses/bsd-license.php
 *
 * on 2012-02-23.)
 */

/* Summary:
 *
 * Implements error printing utilities.
 */

#define __STRICT_ANSI__ 1

#include "test_error.h"
#include <vrpsx_utility.h>
#include <errno.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>


extern void printError(
    where_t where,
    vrpsx_system_t *system,
    char const *operation,
    vrpsx_errno_t ern)
{
    vrpsx_system_error_t *errObj;
    VRPSX_CALL2(system, error_acquire, ern, &errObj);

    print_where(where);
    printf("%s: error %d: %s\n", operation, ern, VRPSX_CALL0(errObj, text));

    VRPSX_COUNTED_REFERENCE_CLEAR(vrpsx_system_error_t, &errObj);
}


extern void *malloc_at(where_t where, size_t size)
{
    void *block = malloc(size);
    if (! block) {
        int ern = errno;
        print_where(where);
        printf("malloc: %s\n", strerror(ern));
    }
    return block;
}
