/* Copyright (c) 2015, Electric Cloud, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/* (As an historical note, the above license instantiates
 * the "BSD 2-Clause License" template that was presented
 * by the Open Source Initiative at
 *
 *   http://www.opensource.org/licenses/bsd-license.php
 *
 * on 2012-02-23.)
 */

/* Summary:
 *
 * Because the C99 standard header <stdint.h> is not available
 * on all platforms, we must replace it when not available.
 *
 * While it is tempting to directly simulate <stdint.h>, we use new
 * names for our typedefs in case some users of this header already
 * simulate <stdint.h> but make a different arbitrary choice between
 * distinct C types having the same size.
 *
 * This replacement may be incomplete, but you should feel
 * free to complete the replacement to the extent desired.
 */

#ifndef VRPSX_STDINT_H
#define VRPSX_STDINT_H 1


#if defined(_MSC_VER)

#if defined(_M_IX86) || defined(_M_X64)

/* Defines intptr_t and uintptr_t.
*/
#include <stddef.h> /* EXCLUDE_FROM_INTERFACE_IDENTIFIER */

typedef intptr_t vrpsx_intptr_t;
typedef uintptr_t vrpsx_uintptr_t;

typedef signed char vrpsx_int8_t;
typedef unsigned char vrpsx_uint8_t;

typedef short vrpsx_int16_t;
typedef unsigned short vrpsx_uint16_t;

typedef int vrpsx_int32_t;
typedef unsigned vrpsx_uint32_t;

typedef __int64 vrpsx_int64_t;
typedef unsigned __int64 vrpsx_uint64_t;

#else /* instruction set */

#error instruction set not yet supported

#endif /* instruction set */

#else /* compiler */

/* Generic version that works with any C99 compiler.
 *
 * At some point we should be able to switch to <stdint.h>, but for now
 * we include <inttypes.h> because it seems to be more widely available.
 */

#include <inttypes.h> /* EXCLUDE_FROM_INTERFACE_IDENTIFIER */

typedef intptr_t vrpsx_intptr_t;
typedef uintptr_t vrpsx_uintptr_t;

typedef int8_t vrpsx_int8_t;
typedef uint8_t vrpsx_uint8_t;

typedef int16_t vrpsx_int16_t;
typedef uint16_t vrpsx_uint16_t;

typedef int32_t vrpsx_int32_t;
typedef uint32_t vrpsx_uint32_t;

typedef int64_t vrpsx_int64_t;
typedef uint64_t vrpsx_uint64_t;

#endif /* compiler */


#endif /* VRPSX_STDINT_H */
